;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "fd-dired" "20260104.335"
  "Find-dired alternative using fd."
  '((emacs "25"))
  :url "https://github.com/yqrashawn/fd-dired"
  :commit "c5b31aec25d20c3219e2635b82efeba532895278"
  :revdesc "c5b31aec25d2"
  :keywords '("tools" "fd" "find" "dired")
  :authors '(("Rashawn Zhang" . "namy.19@gmail.com"))
  :maintainers '(("Rashawn Zhang" . "namy.19@gmail.com")))
